"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ColorTokens = void 0;
const React = require("react");
const util_1 = require("./util");
const { createElement: h } = React;
const astToReact = (ast, code, pos, prefix, as) => {
    if (typeof ast === 'number')
        return [code.slice(pos, pos + ast), ast];
    const [types, tokens, language] = ast;
    const children = [];
    const length = tokens.length;
    let nodeTextLength = 0;
    for (let i = 0; i < length; i++) {
        const token = tokens[i];
        const [node, len] = astToReact(token, code, pos + nodeTextLength, prefix, 'span');
        nodeTextLength += len;
        children.push(node);
    }
    const props = {
        className: prefix + types.shift() + ' ' + types.join(' '),
        'data-lang': language,
    };
    return [h(as, props, ...children), nodeTextLength];
};
const ColorTokens = ({ code, lang, prefix = 'hljs-', as = 'code' }) => {
    const [node, setNode] = React.useState(null);
    const Tag = as;
    React.useEffect(() => {
        setNode(null);
        let unmounted = false;
        (0, util_1.tokens)(code, lang)
            .then((ast) => {
            if (!unmounted) {
                const [node] = astToReact(ast, code, 0, prefix, Tag);
                setNode(node);
            }
        })
            .catch((err) => { });
        return () => {
            unmounted = true;
        };
    }, [code]);
    return node || React.createElement(Tag, null, code);
};
exports.ColorTokens = ColorTokens;
//# sourceMappingURL=ColorTokens.js.map